"""
consumer_grant automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .consumer_app import ConsumerApp
class ConsumerGrant(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app: Optional[ConsumerApp] = Field(default=None, alias="app")
    create_date: Optional[datetime.datetime] = Field(default=None, alias="createDate")
    pass



"""
backend_dashboard_user automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class BackendDashboardUser(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    status: Optional[str] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass



"""
common_form_element_select_option automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class CommonFormElementSelectOption(BaseModel):
    key: Optional[str] = Field(default=None, alias="key")
    value: Optional[str] = Field(default=None, alias="value")
    pass



"""
consumer_token_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class ConsumerTokenUpdate(BaseModel):
    name: Optional[str] = Field(default=None, alias="name")
    expire: Optional[datetime.date] = Field(default=None, alias="expire")
    pass



"""
ConsumerIdentityTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .common_message_exception import CommonMessageException
from .consumer_identity_collection import ConsumerIdentityCollection
from .passthru import Passthru

class ConsumerIdentityTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def redirect(self, identity: str) -> Passthru:
        try:
            path_params = {}
            path_params["identity"] = identity

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/consumer/identity/:identity/redirect", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return Passthru.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def exchange(self, identity: str) -> Passthru:
        try:
            path_params = {}
            path_params["identity"] = identity

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/consumer/identity/:identity/exchange", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return Passthru.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, app_id: int, app_key: str) -> ConsumerIdentityCollection:
        try:
            path_params = {}

            query_params = {}
            query_params["appId"] = app_id
            query_params["appKey"] = app_key

            query_struct_names = []

            url = self.parser.url("/consumer/identity", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return ConsumerIdentityCollection.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
consumer_user_refresh automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class ConsumerUserRefresh(BaseModel):
    refresh_token: Optional[str] = Field(default=None, alias="refresh_token")
    pass



"""
common_form_element_text_area automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_form_element import CommonFormElement
class CommonFormElementTextArea(CommonFormElement):
    mode: Optional[str] = Field(default=None, alias="mode")
    pass



"""
backend_marketplace_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendMarketplaceApp(BaseModel):
    version: Optional[str] = Field(default=None, alias="version")
    description: Optional[str] = Field(default=None, alias="description")
    screenshot: Optional[str] = Field(default=None, alias="screenshot")
    website: Optional[str] = Field(default=None, alias="website")
    download_url: Optional[str] = Field(default=None, alias="downloadUrl")
    sha_hash: Optional[str] = Field(default=None, alias="sha1Hash")
    start_url: Optional[str] = Field(default=None, alias="startUrl")
    pass



"""
backend_marketplace_local_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_marketplace_app import BackendMarketplaceApp
class BackendMarketplaceLocalApp(BackendMarketplaceApp):
    remote: Optional[BackendMarketplaceApp] = Field(default=None, alias="remote")
    pass
